==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/admin/admin_quick_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   admin_quick_edit.lang.inc.php 2016-08-16
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2016 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	// Common
	'PAGE_TITLE'                       => 'QuickEdit',
	'SETTINGS'                         => 'Settings',
	'PROPERTIES'                       => 'Properties',
	'CONFIGURATION'                    => 'Configuration',
	'OVERVIEW'                         => 'Overview',
	'INVENTORY_CHECKLIST'              => 'Inventory Checklist',
	'IS'                               => 'Is',
	'SHOULD'                           => 'Should',
	'CREATED_AT'                       => 'Created at',
	'ACTIVE'                           => 'Active',
	'INACTIVE'                         => 'Inactive',
	'SEARCH'                           => 'Search',
	'TEXT_MODE'                        => 'Mode',
	'TEXT_FILTER_MODE'                 => 'Filtering',
	'TEXT_EDIT_MODE'                   => 'Editing',
	'TEXT_PLEASE_WAIT'                 => 'Please wait',
	'TEXT_READY_TO_DOWNLOAD_DOCUMENT'  => 'Document can be downloaded now',
	'NO_RESULTS_FOR'                   => 'No results for',
	'NUMBER_OF_PIECES'                 => 'Number Of Pieces',
	'UNEXPECTED_REQUEST_ERROR'         => 'Unexpected request error.',
	// Table Column Title
	'ID'                               => 'ID',
	'CATEGORY'                         => 'Category',
	'MANUFACTURER'                     => 'Manufacturer',
	'MODEL'                            => 'Model',
	'NAME'                             => 'Name',
	'COMBINATION'                      => 'Combination',
	'QUANTITY'                         => 'Quantity',
	'SHIPPINGTIME'                     => 'Shippingtime',
	'WEIGHT'                           => 'Weight',
	'SHIPPINGCOSTS'                    => 'Shippingcosts',
	'TAX'                              => 'Tax',
	'PRICE'                            => 'Price',
	'PRICETYPE'                        => 'Pricetype',
	'COMBI_PRICE'                      => 'Price',
	'DISCOUNT'                         => 'Discount',
	'SPECIAL_PRICE'                    => 'Specialprice',
	'SPECIAL_QUANTITY'                 => 'Quantity',
	'EXPIRES_DATE'                     => 'Expires',
	'STATUS'                           => 'Status',
	'ACTIONS'                          => 'Actions',
	// Modal Titles
	'MODAL_TITLE_NODE'                 => 'Node',
	'MODAL_TITLE_SETTINGS'             => 'Settings',
	'MODAL_TITLE_PROPERTIES'           => 'Properties',
	'MODAL_TITLE_SPECIAL_PRICE'        => 'Specialprice',
	'MODAL_TITLE_GRADUATED_PRICES'     => 'Graduated Prices',
	'MODAL_TITLE_DOCUMENT_CREATE'      => 'Create document',
	// Modal Settings
	'COLUMN'                           => 'Column',
	'COLUMNS'                          => 'Columns',
	'ROWS'                             => 'Rows',
	'ROW_HEIGHT_LABEL'                 => 'Height',
	'ROW_HEIGHT_SMALL'                 => 'Small',
	'ROW_HEIGHT_MEDIUM'                => 'Medium',
	'ROW_HEIGHT_LARGE'                 => 'Large',
	// Modal Exceptions
	'NO_PRODUCT_SELECTED'              => 'No product has been selected.',
	'NOTHING_TO_EDIT'                  => 'No changes where detected on the selected product.',
	'EDIT_ERROR'                       => 'Changes where not be able to proceed.',
	// Row Actions,
	'TEXT_VIEW'                        => 'View',
	'TEXT_EDIT'                        => 'Edit',
	'TEXT_PROPERTIES'                  => 'Properties',
	'TEXT_SAVE'                        => 'Save',
	// Buttons
	'BUTTON_SHOW'                      => 'Show',
	'BUTTON_EDIT'                      => 'Edit',
	'BUTTON_PROPERTIES'                => 'Properties',
	'BUTTON_GRADUATED_PRICES'          => 'Graduated Prices',
	'BUTTON_SPECIAL_PRICE'             => 'Specialprice',
	'BUTTON_SAVE'                      => 'Save',
	'BUTTON_CANCEL'                    => 'Cancel',
	'BUTTON_CLOSE'                     => 'Close',
	'BUTTON_CREATE'                    => 'Create',
	'BUTTON_DOWNLOAD'                  => 'Download',
	'BUTTON_DELETE'                    => 'Delete',
	'BUTTON_FILTER'                    => 'Filtering',
	'BUTTON_INVENTORY_DOCUMENT_CREATE' => 'Create Inventorylist',
	'BUTTON_RESET'                     => 'Reset',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Reset to default settings',
	// Tooltips
	'TOOLTIP_FILTER_CATEGORY'          => 'Wildcard search with (*) e.g.: *amp*',
	'TOOLTIP_FILTER_NAME'              => 'Wildcard search with (*) e.g.: 4*1*',
	'TOOLTIP_FILTER_MODEL'             => 'Wildcard search with (*) e.g.: K*27*',
	'TOOLTIP_FILTER_QUANTITY'          => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_PRICE'             => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_DISCOUNT'          => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_SPECIAL_PRICE'     => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_WEIGHT'            => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_SHIPPING_COSTS'    => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_NAME'        => 'Wildcard-Suche mit (*) e.g.: *amp*',
	'TOOLTIP_FILTER_COMBI_MODEL'       => 'Wildcard-Suche mit (*) e.g.: K*27*',
	'TOOLTIP_FILTER_COMBI_EAN'         => 'Wildcard-Suche mit (*) e.g.: *123*',
	'TOOLTIP_FILTER_COMBI_QUANTITY'    => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_WEIGHT'      => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_PRICE'       => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_EDIT_QUANTITY'            => 'Editing values e.g.: (10), (-10 or +10) and (-10% or +10%)',
	'TOOLTIP_EDIT_PRICE'               => 'Editing values e.g.: (20), (-20 or +20) and (-20% or +20%)',
	'TOOLTIP_EDIT_DISCOUNT'            => 'Editing values e.g.: (30)',
	'TOOLTIP_EDIT_SPECIAL_PRICE'       => 'Editing values e.g.: (40), (-40 or +40), (40%), (-40% or +40%)<br>Entering percentage (%) without minus (-) or plus (+) refers to the article price!',
	'TOOLTIP_EDIT_WEIGHT'              => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_SHIPPING_COSTS'      => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_COMBI_QUANTITY'      => 'Editing values e.g.: (10), (-10 or +10) and (-10% or +10%)',
	'TOOLTIP_EDIT_COMBI_WEIGHT'        => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_COMBI_PRICE'         => 'Editing values e.g.: (20), (-20 or +20) and (-20% or +20%)',
	'TOOLTIP_NO_CHANGES'               => 'No changes',
	// Admin info box
	'SUCCESS_PRODUCT_UPDATED'          => 'Changes were successfully updated.',
	
	// Products Properties
	'COMBI_FIX_PRICE'                  => 'Fix',
	'COMBI_CALC_PRICE'                 => 'Calculate',
	// Specials
	'TEXT_DATE_OF_EXPIRY'              => 'Date of expiry:',
	'TEXT_QUANTITY'                    => 'Quantity:',
	'TEXT_NEW_PRICE'                   => 'New Price:',
	'TEXT_SURCHARGE'                   => 'Surcharge:',
	'TEXT_DISCOUNT'                    => 'Discount:',
	'TEXT_STATUS'                      => 'Status:',
	'TEXT_NO_SPECIAL_OFFER'            => 'No special offer configured',
	'TEXT_TITLE_SPECIAL_OFFER'         => 'special offer'
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/english/original_sections/admin/admin_quick_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   admin_quick_edit.lang.inc.php 2021-09-23
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	// Common
	'PAGE_TITLE'                       => 'QuickEdit',
	'SETTINGS'                         => 'Settings',
	'PROPERTIES'                       => 'Product Variants',
	'CONFIGURATION'                    => 'Configuration',
	'OVERVIEW'                         => 'Overview',
	'INVENTORY_CHECKLIST'              => 'Inventory Checklist',
	'IS'                               => 'Is',
	'SHOULD'                           => 'Should',
	'CREATED_AT'                       => 'Created at',
	'ACTIVE'                           => 'Active',
	'INACTIVE'                         => 'Inactive',
	'SEARCH'                           => 'Search',
    'UNCATEGORIZED'                    => 'Uncategorized',
	'TEXT_MODE'                        => 'Mode',
	'TEXT_FILTER_MODE'                 => 'Filtering',
	'TEXT_EDIT_MODE'                   => 'Editing',
	'TEXT_PLEASE_WAIT'                 => 'Please wait',
	'TEXT_READY_TO_DOWNLOAD_DOCUMENT'  => 'Document can be downloaded now',
	'NO_RESULTS_FOR'                   => 'No results for',
	'NUMBER_OF_PIECES'                 => 'Number Of Pieces',
	'UNEXPECTED_REQUEST_ERROR'         => 'Unexpected request error.',
	// Table Column Title
	'ID'                               => 'ID',
	'CATEGORY'                         => 'Category',
	'MANUFACTURER'                     => 'Manufacturer',
	'MODEL'                            => 'Model',
	'NAME'                             => 'Name',
	'COMBINATION'                      => 'Combination',
	'QUANTITY'                         => 'Quantity',
	'SHIPPINGTIME'                     => 'Shippingtime',
	'WEIGHT'                           => 'Weight',
	'SHIPPINGCOSTS'                    => 'Shippingcosts',
	'TAX'                              => 'Tax',
	'PRICE'                            => 'Price',
	'PRICETYPE'                        => 'Pricetype',
	'COMBI_PRICE'                      => 'Price',
	'DISCOUNT'                         => 'Discount',
	'SPECIAL_PRICE'                    => 'Specialprice',
	'SPECIAL_QUANTITY'                 => 'Quantity',
	'EXPIRES_DATE'                     => 'Expires',
	'STATUS'                           => 'Status',
	'ACTIONS'                          => 'Actions',
	// Modal Titles
	'MODAL_TITLE_NODE'                 => 'Node',
	'MODAL_TITLE_SETTINGS'             => 'Settings',
	'MODAL_TITLE_PROPERTIES'           => 'Product Variants',
	'MODAL_TITLE_SPECIAL_PRICE'        => 'Specialprice',
	'MODAL_TITLE_GRADUATED_PRICES'     => 'Graduated Prices',
	'MODAL_TITLE_DOCUMENT_CREATE'      => 'Create document',
	// Modal Settings
	'COLUMN'                           => 'Column',
	'COLUMNS'                          => 'Columns',
	'ROWS'                             => 'Rows',
	'ROW_HEIGHT_LABEL'                 => 'Height',
	'ROW_HEIGHT_SMALL'                 => 'Small',
	'ROW_HEIGHT_MEDIUM'                => 'Medium',
	'ROW_HEIGHT_LARGE'                 => 'Large',
	// Modal Exceptions
	'NO_PRODUCT_SELECTED'              => 'No product has been selected.',
	'NOTHING_TO_EDIT'                  => 'No changes where detected on the selected product.',
	'EDIT_ERROR'                       => 'Changes where not be able to proceed.',
	// Row Actions,
	'TEXT_VIEW'                        => 'View',
	'TEXT_EDIT'                        => 'Edit',
	'TEXT_PROPERTIES'                  => 'Product Variants',
	'TEXT_SAVE'                        => 'Save',
	// Buttons
	'BUTTON_SHOW'                      => 'Show',
	'BUTTON_EDIT'                      => 'Edit',
	'BUTTON_PROPERTIES'                => 'Product Variants',
	'BUTTON_GRADUATED_PRICES'          => 'Graduated Prices',
	'BUTTON_SPECIAL_PRICE'             => 'Specialprice',
	'BUTTON_SAVE'                      => 'Save',
	'BUTTON_CANCEL'                    => 'Cancel',
	'BUTTON_CLOSE'                     => 'Close',
	'BUTTON_CREATE'                    => 'Create',
	'BUTTON_DOWNLOAD'                  => 'Download',
	'BUTTON_DELETE'                    => 'Delete',
	'BUTTON_FILTER'                    => 'Filtering',
	'BUTTON_INVENTORY_DOCUMENT_CREATE' => 'Create Inventorylist',
	'BUTTON_RESET'                     => 'Reset',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Reset to default settings',
	// Tooltips
	'TOOLTIP_FILTER_CATEGORY'          => 'Wildcard search with (*) e.g.: *amp*',
	'TOOLTIP_FILTER_NAME'              => 'Wildcard search with (*) e.g.: 4*1*',
	'TOOLTIP_FILTER_MODEL'             => 'Wildcard search with (*) e.g.: K*27*',
	'TOOLTIP_FILTER_QUANTITY'          => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_PRICE'             => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_DISCOUNT'          => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_SPECIAL_PRICE'     => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_WEIGHT'            => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_SHIPPING_COSTS'    => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_NAME'        => 'Wildcard-Suche mit (*) e.g.: *amp*',
	'TOOLTIP_FILTER_COMBI_MODEL'       => 'Wildcard-Suche mit (*) e.g.: K*27*',
	'TOOLTIP_FILTER_COMBI_EAN'         => 'Wildcard-Suche mit (*) e.g.: *123*',
	'TOOLTIP_FILTER_COMBI_QUANTITY'    => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_WEIGHT'      => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_FILTER_COMBI_PRICE'       => 'Filter values e.g.: (1), (2-3), (<4 or 4>) and (>5 or 5<)',
	'TOOLTIP_EDIT_QUANTITY'            => 'Editing values e.g.: (10), (-10 or +10) and (-10% or +10%)',
	'TOOLTIP_EDIT_PRICE'               => 'Editing values e.g.: (20), (-20 or +20) and (-20% or +20%)',
	'TOOLTIP_EDIT_DISCOUNT'            => 'Editing values e.g.: (30)',
	'TOOLTIP_EDIT_SPECIAL_PRICE'       => 'Editing values e.g.: (40), (-40 or +40), (40%), (-40% or +40%)<br>Entering percentage (%) without minus (-) or plus (+) refers to the article price!',
	'TOOLTIP_EDIT_WEIGHT'              => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_SHIPPING_COSTS'      => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_COMBI_QUANTITY'      => 'Editing values e.g.: (10), (-10 or +10) and (-10% or +10%)',
	'TOOLTIP_EDIT_COMBI_WEIGHT'        => 'Editing values e.g.: (5), (-5 or +5) and (-5% or +5%)',
	'TOOLTIP_EDIT_COMBI_PRICE'         => 'Editing values e.g.: (20), (-20 or +20) and (-20% or +20%)',
	'TOOLTIP_NO_CHANGES'               => 'No changes',
	// Admin info box
	'SUCCESS_PRODUCT_UPDATED'          => 'Changes were successfully updated.',
	
	// Products Properties
	'COMBI_FIX_PRICE'                  => 'Fix',
	'COMBI_CALC_PRICE'                 => 'Calculate',
	// Specials
	'TEXT_DATE_OF_EXPIRY'              => 'Date of expiry:',
	'TEXT_QUANTITY'                    => 'Quantity:',
	'TEXT_NEW_PRICE'                   => 'New Price:',
	'TEXT_SURCHARGE'                   => 'Surcharge:',
	'TEXT_DISCOUNT'                    => 'Discount:',
	'TEXT_STATUS'                      => 'Status:',
	'TEXT_NO_SPECIAL_OFFER'            => 'No special offer configured',
	'TEXT_TITLE_SPECIAL_OFFER'         => 'special offer'
];
